//
//  FGHUDWindow.m
//  Created by Francesco on 1/9/06.
//  Copyright 2006 Softech di Germinara Francesco
//
//  www.germinara.it
//  info@germinara.it
//
//  All rights reserved.
/////////////////////////////////////////////////////////


#import "FGHUDWindow.h"

@implementation FGHUDWindow


- (id)initWithContentRect:(NSRect)contentRect styleMask:(unsigned int)style
				  backing:(NSBackingStoreType)bufferingType defer:(BOOL)flag
{
	//Calcolo le coodinate per centrare il logo nello schermo
	NSScreen* mainScreen = [NSScreen mainScreen];
	NSRect screen = [mainScreen frame];
	NSPoint center = NSMakePoint(screen.size.width / 2, screen.size.height / 2);
	contentRect.origin.x = center.x - (contentRect.size.width / 2);
	contentRect.origin.y = center.y - (contentRect.size.height / 2);
	
	// Uso NSBorderlessWindowMask come stile nella creazione della finestra in modo da avere una finestra senza barra titolo e senza bordo
	id window = [super initWithContentRect:contentRect styleMask:NSBorderlessWindowMask backing:bufferingType defer:flag];
	if (window){ //Ok, procedo
		//Imposto la trasparenza
		[window setOpaque:NO];
	    //Elimino l'ombra	
		[window setHasShadow:NO];
		//Imposto lo il color di background a trasparente
		[window setBackgroundColor: [NSColor clearColor]];
        //La porto in primo piano rispetto a tutte le alte finestre
		[window setLevel:NSFloatingWindowLevel]; 
		//Imposto informazioni relative al pulsante di chiusura personalizzato
	    nButtonSpacing=24;
		nHorzCloseButtonOffset=5;
        nVertCloseButtonOffset=20;
		bBtnHeight=20;
		bBtnWidth=22;
		
	 }
	return window;
}

- (void)awakeFromNib {
	NSRect	frame = [self frame];
	NSRect	hoverRect = NSMakeRect(nHorzCloseButtonOffset, frame.size.height - nVertCloseButtonOffset, nButtonSpacing, bBtnHeight);
		   	
	[self addCloseButton]; //Aggiungo il bottone 
	
	nZoneTrackingTag = [[self contentView] addTrackingRect:hoverRect owner:self userData:nil assumeInside:NO]; //imposto area di tracking
}

- (void)addCloseButton{
	NSRect	frame = [self frame];

	closeButton = [[NSButton alloc] initWithFrame:NSMakeRect(nHorzCloseButtonOffset, frame.size.height - nVertCloseButtonOffset, bBtnWidth, bBtnHeight)];
	[closeButton setButtonType:NSMomentaryChangeButton];
	[closeButton setImage:[NSImage imageNamed:@"stop.0.tiff"]];
	[closeButton setAlternateImage:[NSImage imageNamed:@"stop.2.tiff"]];
	[closeButton setBordered:NO];
	[closeButton setAction:@selector(close)]; //Imposto l'azione di CLOSE per il pulsante appena creato
	[[self contentView] addSubview:closeButton]; //Aggiungo il pulsante alla vista principale
}

- (void)mouseEntered:(NSEvent *)event{
	if ([event trackingNumber] == nZoneTrackingTag)
		[closeButton setImage:[NSImage imageNamed:@"stop.2.tiff"]];
}

- (void)mouseExited:(NSEvent *)event{
	if ([event trackingNumber] == nZoneTrackingTag)
	{
		if ([self isKeyWindow])
		{
			[closeButton setImage:[NSImage imageNamed:@"stop.1.tiff"]];
		}
	}
}

- (void)windowDidBecomeKey:(NSNotification *)notification
{
	[closeButton setImage:[NSImage imageNamed:@"stop.1.tiff"]];
	[closeButton setNeedsDisplay:YES];
}

- (void)windowDidResignKey:(NSNotification *)notification
{
	[closeButton setNeedsDisplay:YES];
}

- (void)windowWillClose:(NSNotification *)aNotification
{

}

// Per default, finestre senza bordo non possono diventare key window o main window
- (BOOL)canBecomeKeyWindow
{
	return YES;
}

- (BOOL)canBecomeMainWindow
{
	return YES;
}


@end
